@@ -11,10 +11,10 @@ import pickle
 import re
 import tarfile
 import time
+import json
 
 import numpy as np
 import PIL
-import simplejson
 
 from . import gopen
 
@@ -58,7 +58,7 @@ def bytestr(data):
     return str(data).encode("ascii")
 
 
-def torch_save_object(data):
+def torch_dumps(data):
     import io
     import torch
 
@@ -82,17 +82,17 @@ def make_handlers():
     for extension in ["pyd", "pickle"]:
         handlers[extension] = pickle.dumps
     for extension in ["pth"]:
-        handlers[extension] = torch_save_object
+        handlers[extension] = torch_dumps
     for extension in ["json", "jsn"]:
-        handlers[extension] = lambda x: simplejson.dumps(x).encode("utf-8")
+        handlers[extension] = lambda x: json.dumps(x).encode("utf-8")
     for extension in ["ten", "tb"]:
         from . import tenbin
 
         def f(x):  # skipcq: PYL-E0102
             if isinstance(x, list):
-                return tenbin.encode_buffer(x)
+                return memoryview(tenbin.encode_buffer(x))
             else:
-                return tenbin.encode_buffer([x])
+                return memoryview(tenbin.encode_buffer([x]))
 
         handlers[extension] = f
     try:
@@ -249,11 +249,11 @@ class TarWriter:
         total = 0
         obj = self.encoder(obj)
         if "__key__" not in obj:
-            raise ValueError(f"object must contain a __key__")
+            raise ValueError("object must contain a __key__")
         for k, v in list(obj.items()):
             if k[0] == "_":
                 continue
-            if not isinstance(v, bytes):
+            if not isinstance(v, (bytes, bytearray, memoryview)):
                 raise ValueError(
                     f"{k} doesn't map to a bytes after encoding ({type(v)})"
                 )
@@ -273,7 +273,7 @@ class TarWriter:
             ti.mode = self.mode
             ti.uname = self.user
             ti.gname = self.group
-            if not isinstance(v, (bytes)):
+            if not isinstance(v, (bytes, bytearray, memoryview)):
                 raise ValueError(f"converter didn't yield bytes: {k}, {type(v)}")
             stream = io.BytesIO(v)
             self.tarstream.addfile(ti, stream)
@@ -291,7 +291,9 @@ class ShardWriter:
 
     """
 
-    def __init__(self, pattern, maxcount=100000, maxsize=3e9, post=None, **kw):
+    def __init__(
+        self, pattern, maxcount=100000, maxsize=3e9, post=None, start_shard=0, **kw
+    ):
         self.verbose = 1
         self.kw = kw
         self.maxcount = maxcount
@@ -299,7 +301,7 @@ class ShardWriter:
         self.post = post
 
         self.tarstream = None
-        self.shard = 0
+        self.shard = start_shard
         self.pattern = pattern
         self.total = 0
         self.count = 0
